View source: R/add_topography.R
| add_topography | R Documentation |
Initializes topography and land cover type for a set of target locations
add_topography(x, dem, progress = TRUE)
add_land_cover(
x,
land_cover_map,
wildland = NULL,
agriculture = NULL,
rock = NULL,
artificial = NULL,
water = NULL,
progress = TRUE
)
x |
An object of class |
dem |
A digital elevation model (class |
progress |
A logical flag to print console output |
land_cover_map |
An object of class |
wildland, agriculture, rock, artificial, water |
Strings indicating the mapping from the legend of land_cover_map. |
The user should manually define the mapping of land cover classes in land_cover_map to the land cover types
used in medfateland.
Function add_topography() returns a modified object of class sf with columns:
id: Numeric location identifiers (if not existing).
elevation: Elevation above sea level (in m).
slope: Slope (in degrees).
aspect: Aspect (in degrees).
land_cover_type: Land cover type.
Function add_land_cover() returns a modified object of class sf with new column:
id: Numeric location identifiers (if not existing).
land_cover_type: Land cover type.
check_topography(), check_land_cover()
# See package vignettes 'Preparing inputs'
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.