View source: R/default_dispersal_control.R
| default_dispersal_control | R Documentation |
Defines default control parameters for dispersal process
default_dispersal_control()
A list with the following items:
distance_step [= 25]: Distance step in meters.
maximum_dispersal_distance [= 3000]: Maximum dispersal distance in meters.
min_percent [= 1]: A minimum percent of seed bank to retain entry in seedBank element of forest.
stochastic_resampling [= FALSE]: A flag to indicate that stochastic resampling of stands is performed.
Miquel De Cáceres Ainsa, CREAF
spwb_land, fordyn_scenario dispersal
default_dispersal_control()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.