View source: R/extract_variables.R
| extract_variables | R Documentation |
Extract or estimate variables from landscape objects (class 'sf').
extract_variables(x, vars = "land_cover_type", SpParams = NULL, ...)
plot_variable(x, variable = "land_cover_type", SpParams = NULL, r = NULL, ...)
x |
An object of class |
vars |
A string vector with the name of the variables to extract (see details). |
SpParams |
A data frame with species parameters (see |
... |
Additional arguments (not used). |
variable |
A string with the name of the variables to draw (see details). |
r |
An object of class |
The following string values are available for vars.
Topography:
"elevation": Elevation in m.
"slope": Slope in degrees.
"aspect": Slope in degrees.
"land_cover_type": Land cover type.
Soil:
"soil_vol_extract": Total water extractable volume (mm).
"soil_vol_sat": Total water volume at saturation (mm).
"soil_vol_fc": Total water volume at field capacity (mm).
"soil_vol_wp": Total water volume at wilting point (mm).
"soil_vol_curr": Current total water volume (mm).
"soil_rwc_curr": Current soil relative water content (%).
"soil_rew_curr": Current soil relative extractable water (%).
"soil_theta_curr": Current soil moisture content (% vol.)
"soil_psi_curr": Current soil water potential (MPa).
Watershed:
"depth_to_bedrock": Depth to bedrock (m).
"bedrock_porosity": Bedrock porosity.
"bedrock_conductivity": Bedrock conductivity (m/day).
"aquifer_elevation": Aquifer elevation over bedrock (m).
"depth_to_aquifer": Depth to aquifer (m).
"aquifer": Aquifer volume (mm).
"snowpack": Snowpack water equivalent (mm).
Forest stand:
"basal_area": Basal area (m2/ha).
"tree_density": Tree density (ind/ha).
"mean_tree_height": Mean tree height (cm).
"dominant_tree_height": Dominant tree height (cm).
"dominant_tree_diameter": Dominant tree diameter (cm).
"quadratic_mean_tree_diameter": Quadratic mean tree diameter (cm).
"hart_becking_index": Hart-Becking index.
"leaf_area_index": Leaf area index (m2/m2).
"foliar_biomass": Foliar biomass (kg/m2).
"fuel_loading": Fine live fuel loading (kg/m2).
"shrub_volume": Shrub volume (m3/m2).
Function extract_variables() returns an object of class sf with the desired variables.
Function plot_variables() returns a ggplot object.
Miquel De Cáceres Ainsa, CREAF.
forest, soil, summary.forest, shinyplot_land
# Load data and species parameters from medfate
data(example_ifn)
data(SpParamsMED)
# Calculate basal area and leaf area index
# for all forest stands
extract_variables(example_ifn, vars = c("basal_area", "leaf_area_index"),
SpParams = SpParamsMED)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.