shinyplot.spwb_land: Shiny app with interactive plots and maps of watershed...

View source: R/shinyplot_land.R

shinyplot.spwb_landR Documentation

Shiny app with interactive plots and maps of watershed simulation results

Description

Creates a shiny app with interactive plots for simulation results

Usage

## S3 method for class 'spwb_land'
shinyplot(x, r = NULL, ...)

## S3 method for class 'growth_land'
shinyplot(x, r = NULL, ...)

## S3 method for class 'fordyn_land'
shinyplot(x, r = NULL, ...)

Arguments

x

An object of class spwb_land, growth_land or fordyn_land.

r

An object of class SpatRaster, defining the raster topology.

...

Additional parameters for function shinyplot (not used).

Value

An object that represents the shiny app

Author(s)

Miquel De Cáceres Ainsa, CREAF

See Also

spwb_land, plot.spwb_land, plot_variable


medfateland documentation built on May 7, 2026, 1:06 a.m.