unnest_summary: Extracts cell simulation summaries

View source: R/plot_summary.R

unnest_summaryR Documentation

Extracts cell simulation summaries

Description

Extracts cell simulation summaries

Usage

unnest_summary(x)

Arguments

x

An object of class sf, with simulation summaries. Alternatively an object of class spwb_land, growth_land or fordyn_land.

Details

Appropriate input objects for x can be originated from calls to simulation_summary. Alternatively, if summary functions were specified at the time of performing simulations, the result of the spatial simulation function (e.g. spwb_spatial) will already contain the summaries. A special case is made for spwb_land, growth_land, and fordyn_land, that are accepted inputs as x, because their child element 'sf' is used.

Value

An sf object with all cell summaries.

See Also

plot_summary, spwb_spatial, spwb_land, simulation_summary


medfateland documentation built on May 7, 2026, 1:06 a.m.