powered by
Updates the state of a spatial object 'x' according to the final state in simulation outcome 'y'
update_landscape(x, y)
An object of class sf with modified state variables.
sf
An object of class sf with the corresponding landscape columns.
The object resulting of a simulation previously carried on x using spwb_spatial, growth_spatial, spwb_land, etc.
x
spwb_spatial
growth_spatial
spwb_land
Miquel De Cáceres Ainsa, CREAF.
spwb_spatial, spwb_spatial_day, spwb_land
spwb_spatial_day