Initializes topography and land cover type for a set of target locations
add_topography(x, dem, progress = TRUE)add_land_cover(
x,
land_cover_map,
wildland = NULL,
agriculture = NULL,
rock = NULL,
artificial = NULL,
water = NULL,
progress = TRUE
)
Function add_topography() returns a modified object of class sf with columns:
id: Numeric location identifiers (if not existing).
elevation: Elevation above sea level (in m).
slope: Slope (in degrees).
aspect: Aspect (in degrees).
land_cover_type: Land cover type.
Function add_land_cover() returns a modified object of class sf with new column:
id: Numeric location identifiers (if not existing).
land_cover_type: Land cover type.
An object of class sf
A digital elevation model (class SpatRaster) with meters as units
A logical flag to print console output
An object of class SpatRaster of land cover type. If missing, all locations are considered 'wildland'.
Strings indicating the mapping from the legend of land_cover_map.
The user should manually define the mapping of land cover classes in land_cover_map to the land cover types
used in medfateland.
check_topography(), check_land_cover()
# See package vignettes 'Preparing inputs'
Run the code above in your browser using DataLab