# A scenario with three management units and annual demand for two species
scen_1 <- create_management_scenario(3, c("Quercus ilex" = 1000, "Pinus nigra" = 2000))
# A scenario like the former, but with total annual demand changing as a function of
# prescribed extraction rates (second and third years)
scen_2 <- create_management_scenario(3,
c("Quercus ilex" = 1000, "Pinus nigra" = 2000),
c("2002" = 30, "2003" = 50))
# A scenario with as many management units as rows in 'defaultPrescriptionsBySpecies'
# and not based on demand
data("defaultPrescriptionsBySpecies")
scen_3 <- create_management_scenario(defaultPrescriptionsBySpecies)
# A scenario with three management units and annual demand for one species group
# and a third species
scen_4 <- create_management_scenario(3, c("Quercus ilex/Quercus pubescens" = 1000,
"Pinus nigra" = 2000))
Run the code above in your browser using DataLab