Learn R Programming

medfateland (version 2.8.1)

default_dispersal_control: Default control parameters for dispersal

Description

Defines default control parameters for dispersal process

Usage

default_dispersal_control()

Arguments

Value

A list with the following items:

  • distance_step [= 25]: Distance step in meters.

  • maximum_dispersal_distance [= 3000]: Maximum dispersal distance in meters.

  • min_percent [= 1]: A minimum percent of seed bank to retain entry in seedBank element of forest.

  • stochastic_resampling [= FALSE]: A flag to indicate that stochastic resampling of stands is performed.

Author

Miquel De Cáceres Ainsa, CREAF

See Also

spwb_land, fordyn_scenario dispersal

Examples

Run this code
default_dispersal_control()

Run the code above in your browser using DataLab