powered by
Defines default control parameters for dispersal process
default_dispersal_control()
A list with the following items:
distance_step [= 25]: Distance step in meters.
distance_step [= 25]
maximum_dispersal_distance [= 3000]: Maximum dispersal distance in meters.
maximum_dispersal_distance [= 3000]
min_percent [= 1]: A minimum percent of seed bank to retain entry in seedBank element of forest.
min_percent [= 1]
seedBank
forest
stochastic_resampling [= FALSE]: A flag to indicate that stochastic resampling of stands is performed.
stochastic_resampling [= FALSE]
Miquel De Cáceres Ainsa, CREAF
spwb_land, fordyn_scenario dispersal
spwb_land
fordyn_scenario
dispersal
Run the code above in your browser using DataLab