- sf
An object of class sf with the following columns:
geometry: Spatial geometry.
id: Stand identifiers.
elevation: Elevation above sea level (in m).
slope: Slope (in degrees).
aspect: Aspect (in degrees).
forest: Objects of class forest.
soil: Objects of class soil.
state: Objects of class spwbInput or growthInput (optional).
meteo: Data frames with weather data (required if parameter meteo = NULL).
management_unit: Management unit corresponding to each stand.
represented_area_ha: Area represented by each stand in hectares.
ignition_weights: Relative weights to determine stands to be burned. Optional, relevant when
fire_regime is supplied only).
local_control: A list of control parameters (optional). Used to override function parameter local_control for specific stands (values can be NULL for the remaining ones).
Alternatively, the user may supply the result of a previous call to fordyn_scenario, where
to continue simulations.
- SpParams
A data frame with species parameters (see SpParamsMED).
- meteo
Meteorology data (see fordyn_spatial).
- management_scenario
A list defining the management scenario (see create_management_scenario)
- volume_function
A function accepting a forest object or a tree data table, and a species parameter table, as input and
returning the wood volume (m3/ha) corresponding to each tree cohort. The function may accept additional arguments.
If NULL, the default volume function is used (not recommended!).
- volume_arguments
List with additional arguments for the volume function.
- local_control
A list of local model control parameters (see defaultControl).
- dispersal_control
A list of dispersal control parameters (see default_dispersal_control). If NULL, then dispersal is not simulated.
- dates
A Date object with the days of the period to be simulated. If NULL, then the whole period of meteo is used.
- CO2ByYear
A named numeric vector with years as names and atmospheric CO2 concentration (in ppm) as values. Used to specify annual changes in CO2 concentration along the simulation (as an alternative to specifying daily values in meteo).
- fire_regime
A list of parameters defining the fire regime (see create_fire_regime) or
a matrix representing a fire regime instance (see fire_regime_instance).
If NULL, wildfires are not simulated. Details are given in fordyn_spatial.
- summary_function
An appropriate function to calculate summaries from an object of class 'fordyn' (e.g., summary.fordyn).
- summary_arguments
List with additional arguments for the summary function.
- parallelize
Boolean flag to try parallelization (will use all clusters minus one).
- num_cores
Integer with the number of cores to be used for parallel computation.
- chunk_size
Integer indicating the size of chunks to be sent to different processes (by default, the number of spatial elements divided by the number of cores).
- progress
Boolean flag to display progress information for simulations.
- verbose
Boolean flag to display additional console output.