| plot_summary | R Documentation |
Produces graphical output of the summaries of a simulation models
plot_summary(x, variable, date, r = NULL, ...)
x |
An object of class |
variable |
The variable to be drawn. |
date |
The date of the summary to be plotted. |
r |
An object of class |
... |
Additional parameters (passed to scale definition, such as |
Appropriate input objects for x can be originated from calls to simulation_summary.
Alternatively, if summary functions were specified at the time of performing simulations,
the result of the spatial simulation function (e.g. spwb_spatial)
will already contain the summaries. A special case is made for spwb_land, growth_land,
and fordyn_land, that are accepted inputs as x, because their child element 'sf' is used.
An object of class ggplot.
Miquel De Cáceres Ainsa, CREAF.
unnest_summary, spwb_spatial, spwb_land, simulation_summary
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.