Learn R Programming

medfateland (version 2.8.1)

shinyplot.spwb_land: Shiny app with interactive plots and maps of watershed simulation results

Description

Creates a shiny app with interactive plots for simulation results

Usage

# S3 method for spwb_land
shinyplot(x, r = NULL, ...)

# S3 method for growth_land shinyplot(x, r = NULL, ...)

# S3 method for fordyn_land shinyplot(x, r = NULL, ...)

Value

An object that represents the shiny app

Arguments

x

An object of class spwb_land, growth_land or fordyn_land.

r

An object of class SpatRaster, defining the raster topology.

...

Additional parameters for function shinyplot (not used).

Author

Miquel De Cáceres Ainsa, CREAF

See Also

spwb_land, plot.spwb_land, plot_variable