| unnest_summary | R Documentation |
Extracts cell simulation summaries
unnest_summary(x)
x |
An object of class |
Appropriate input objects for x can be originated from calls to simulation_summary.
Alternatively, if summary functions were specified at the time of performing simulations,
the result of the spatial simulation function (e.g. spwb_spatial)
will already contain the summaries. A special case is made for spwb_land, growth_land,
and fordyn_land, that are accepted inputs as x, because their child element 'sf' is used.
An sf object with all cell summaries.
plot_summary, spwb_spatial, spwb_land, simulation_summary
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.